@@ -782,9 +782,32 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
             epochkpis_series = daily_df[['year', 'month', me_strat]].groupby(['year', 'month']).apply(go_comp_kpi)
             epochkpis_df = pd.DataFrame().from_records(epochkpis_series.values)
             epochkpis_df.index = epochkpis_series.index
+            epochkpis_df = epochkpis_df.rename(columns={
+                'simple_return': 'epoch realized return',
+                'annual_return': 'epoch realized annualized return',
+                'annual_volatility': 'epoch realized annualized volatility',
+                'sharpe': 'epoch realized sharpe ratio',
+                'calmar': 'epoch realized calmar ratio',
+                'mdd': 'epoch realized max drawdown'})
             if write_file:
                 writer = pd.ExcelWriter(local_root_directory + f'epoch_{me_strat_name}_{title}.xlsx',
                                         engine='xlsxwriter')
                 epochkpis_df.to_excel(writer, sheet_name='kpis per epoch')
                 writer.save()
+            if plot_html:
+
+                to_plot_df = epochkpis_df[
+                    ['epoch realized return', 'epoch realized max drawdown']].copy()
+                fig = realtime_plotting_utility.plot_multiple_bar_series(
+                    data_df=to_plot_df[['epoch realized return']] * 100.,
+                    logy=False, split=False,
+                    put_on_same_scale=False,
+                    title=f'epoch realized return in percent')
+                fig.show()
+                fig = realtime_plotting_utility.plot_multiple_bar_series(
+                    data_df=to_plot_df[['epoch realized max drawdown']] * 100.,
+                    logy=False, split=False,
+                    put_on_same_scale=False,
+                    title=f'epoch realized max drawdown in percent')
+                fig.show()
     return data[dd_list]
